
from scuttle.parsers.accesslog import AccessLogParser

PARSERS = {
    'accesslog': AccessLogParser(),
}
